import { INPUT_EVENT as n, CHANGE_EVENT as a, FOCUS_EVENT as r, BLUR_EVENT as p } from "../../../constants/index.js";
import { isString as t } from "../../../utils/lodash/index.js";
const c = {
  /** 绑定值 */
  modelValue: {
    type: [Number, String],
    default: ""
  },
  /**
   * 类型
   *
   * 文字输入框或者密码输入框
   *
   * @values text password number
   * @default text
   */
  type: {
    type: String,
    default: "text"
  },
  /**
   * 尺寸
   *
   * @values large default small
   */
  size: {
    type: String
  },
  /**
   * 是否禁用
   *
   * @see disabled https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-disabled
   */
  disabled: {
    type: Boolean
  },
  /**
   * 是否只读
   *
   * @see readonly https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-readonly
   */
  readonly: {
    type: Boolean
  },
  /**
   * 最大输入长度
   *
   * @see maxlength https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-maxlength
   */
  maxlength: {
    type: Number
  },
  /**
   * 是否自动获取焦点
   *
   * @see autofocus https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-autofocus
   */
  autofocus: {
    type: Boolean
  },
  /**
   * 原生 name 属性
   *
   * @see name https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-name
   */
  name: {
    type: String
  },
  /**
   * 占位符
   *
   * @see placeholder https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-placeholder
   */
  placeholder: {
    type: String
  },
  /** 是否可清除 */
  clearable: {
    type: Boolean
  },
  /** 是否可搜索 */
  search: {
    type: Boolean
  },
  /** 是否显示查看密码的按钮 */
  showPassword: {
    type: Boolean
  },
  /** 后缀 icon */
  suffixIcon: {
    type: Object
  },
  /** 前缀 icon */
  prefixIcon: {
    type: Object
  },
  /**
   * 是否开启自动填充特性提示
   *
   * 注意这不是一个布尔属性！
   *
   * 详情配置可参考
   *
   * @see HTML属性autocomplete https://developer.mozilla.org/zh-CN/docs/Web/HTML/Attributes/autocomplete
   * @see autocomplete https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#autocomplete
   */
  autocomplete: {
    type: String,
    default: "off"
  }
}, i = {
  [n]: (e) => t(e),
  [a]: (e) => t(e),
  [r]: (e) => e instanceof FocusEvent,
  [p]: (e) => e instanceof FocusEvent,
  search: (e, o) => o instanceof Event,
  clear: () => !0
};
export {
  i as Emits,
  c as Props
};
